==> 0.0.10.tar.gz: lib/src/pages/registration_page.dart <==
import 'package:ametory_ui/ametory_ui.dart';
import 'package:ametory_ui/src/styles/color.dart';
import 'package:ametory_ui/src/utils/helper/layout.dart';
import 'package:ametory_ui/src/widgets/widget_size.dart';
import 'package:flutter/material.dart';

class MyRegistrationPage extends StatefulWidget {
  final Color? backgroundColor;
  final Color? boxColor;
  final BorderRadius? boxRadius;
  final Widget? title;
  final Widget? subtitle;
  final Widget? footer;
  final List<BoxShadow>? boxShadow;
  final double? boxWidth;
  final double? boxHeight;
  final TextEditingController? nameController;
  final TextEditingController? emailController;
  final TextEditingController? phoneController;
  final TextEditingController? addressController;
  final TextEditingController? passwordController;
  final TextEditingController? confirmController;
  final Function()? onSubmit;
  MyRegistrationPage(
      {Key? key,
      this.boxWidth,
      this.backgroundColor,
      this.boxColor,
      this.boxRadius,
      this.boxShadow,
      this.title,
      this.subtitle,
      this.boxHeight,
      this.onSubmit,
      this.nameController,
      this.footer,
      this.emailController,
      this.phoneController,
      this.addressController,
      this.passwordController,
      this.confirmController})
      : super(key: key);

  @override
  State<MyRegistrationPage> createState() => _MyRegistrationPageState();
}

class _MyRegistrationPageState extends State<MyRegistrationPage> {
  double? width;
  double? height;
  final _key = GlobalKey();
  bool obscureText = true;

// This function is trggered somehow after build() called
  @override
  Widget build(BuildContext context) {
    return Container(
      width: double.infinity,
      height: double.infinity,
      decoration: BoxDecoration(
          color: widget.backgroundColor ?? MyColor.info,
          gradient: LinearGradient(colors: [
            MyColor.info,
            MyColor.info.shade100,
          ], begin: Alignment.topCenter, end: Alignment.bottomCenter)),
      child: Container(
        padding:
            EdgeInsets.all(ResponsiveWidget.isSmallScreen(context) ? 20 : 40),
        alignment: Alignment.center,
        child: WidgetSize(
          onChange: (Size size) {
            width = size.width;
            height = size.height;
            setState(() {});
          },
          child: Container(
              decoration: BoxDecoration(
                  boxShadow: widget.boxShadow ??
                      [const BoxShadow(color: Colors.black45, blurRadius: 10)],
                  color: widget.boxColor ?? Colors.white,
                  borderRadius: widget.boxRadius ?? BorderRadius.circular(10)),
              padding: EdgeInsets.all(
                  ResponsiveWidget.isSmallScreen(context) ? 20 : 40),
              width: ResponsiveWidget.isSmallScreen(context)
                  ? double.infinity
                  : widget.boxWidth ?? 800,
              // height: widget.boxHeight ?? MediaQuery.of(context).size.height,
              child: SingleChildScrollView(
                child: Column(
                  children: [
                    widget.title ??
                        Text(
                          "Pendaftaran",
                          style: MyTypo.heading1,
                        ),
                    vspace(10),
                    widget.subtitle ??
                        Text(
                          "Silakan isi data lengkap anda",
                          style: MyTypo.bodyText1,
                        ),
                    vspace(40),
                    Input(
                      leading: !ResponsiveWidget.isLargeScreen(context)
                          ? null
                          : SizedBox(
                              child: Row(
                                children: [
                                  SizedBox(
                                    width: width != null ? width! / 8 : 0,
                                    child: Text(
                                      "Nama Lengkap",
                                      style: MyTypo.heading4.copyWith(
                                          fontSize: 12, color: Colors.black54),
                                    ),
                                  ),
                                  hspace(10)
                                ],
                              ),
                            ),
                      controller: widget.nameController,
                      hintText: "Nama Lengkap",
                      padding: const EdgeInsets.fromLTRB(10, 0, 10, 0),
                    ),
                    vspace(20),
                    Row(
                      children: [
                        Flexible(
                          child: Input(
                            keyboardType: TextInputType.emailAddress,
                            leading: !ResponsiveWidget.isLargeScreen(context)
                                ? null
                                : SizedBox(
                                    child: Row(
                                      children: [
                                        SizedBox(
                                          width: width != null ? width! / 8 : 0,
                                          child: Text(
                                            "Email",
                                            style: MyTypo.heading4.copyWith(
                                                fontSize: 12,
                                                color: Colors.black54),
                                          ),
                                        ),
                                        hspace(10)
                                      ],
                                    ),
                                  ),
                            controller: widget.emailController,
                            hintText: "Email",
                            padding: const EdgeInsets.fromLTRB(10, 0, 10, 0),
                          ),
                        ),
                        hspace(10),
                        Flexible(
                          child: Input(
                            keyboardType: TextInputType.number,
                            leading: !ResponsiveWidget.isLargeScreen(context)
                                ? null
                                : SizedBox(
                                    child: Row(
                                      children: [
                                        SizedBox(
                                          width: width != null ? width! / 8 : 0,
                                          child: Text(
                                            "Telepon",
                                            style: MyTypo.heading4.copyWith(
                                                fontSize: 12,
                                                color: Colors.black54),
                                          ),
                                        ),
                                        hspace(10)
                                      ],
                                    ),
                                  ),
                            controller: widget.phoneController,
                            hintText: "Telepon",
                            padding: const EdgeInsets.fromLTRB(10, 0, 10, 0),
                          ),
                        ),
                      ],
                    ),
                    vspace(20),
                    Row(
                      children: [
                        Flexible(
                          child: Input(
                            obscureText: obscureText,
                            leading: !ResponsiveWidget.isLargeScreen(context)
                                ? null
                                : SizedBox(
                                    child: Row(
                                      children: [
                                        SizedBox(
                                          width: width != null ? width! / 8 : 0,
                                          child: Text(
                                            "Password",
                                            style: MyTypo.heading4.copyWith(
                                                fontSize: 12,
                                                color: Colors.black54),
                                          ),
                                        ),
                                        hspace(10)
                                      ],
                                    ),
                                  ),
                            controller: widget.passwordController,
                            hintText: "Password",
                            padding: const EdgeInsets.fromLTRB(10, 0, 10, 0),
                            trailing: InkWell(
                              onTap: () =>
                                  setState(() => obscureText = !obscureText),
                              child: const Icon(
                                Icons.remove_red_eye_outlined,
                                size: 16,
                                color: Colors.black38,
                              ),
                            ),
                          ),
                        ),
                        hspace(10),
                        Flexible(
                          child: Input(
                            obscureText: obscureText,
                            leading: !ResponsiveWidget.isLargeScreen(context)
                                ? null
                                : SizedBox(
                                    child: Row(
                                      children: [
                                        SizedBox(
                                          width: width != null ? width! / 8 : 0,
                                          child: Text(
                                            "Ulangi",
                                            style: MyTypo.heading4.copyWith(
                                                fontSize: 12,
                                                color: Colors.black54),
                                          ),
                                        ),
                                        hspace(10)
                                      ],
                                    ),
                                  ),
                            controller: widget.confirmController,
                            hintText: "Ulangi Password",
                            padding: const EdgeInsets.fromLTRB(10, 0, 10, 0),
                            trailing: InkWell(
                              onTap: () =>
                                  setState(() => obscureText = !obscureText),
                              child: const Icon(
                                Icons.remove_red_eye_outlined,
                                size: 16,
                                color: Colors.black38,
                              ),
                            ),
                          ),
                        ),
                      ],
                    ),
                    vspace(20),
                    Input(
                      height: null,
                      maxLine: 3,
                      leading: !ResponsiveWidget.isLargeScreen(context)
                          ? null
                          : SizedBox(
                              child: Row(
                                children: [
                                  SizedBox(
                                    width: width != null ? width! / 8 : 0,
                                    child: Text(
                                      "Alamat",
                                      style: MyTypo.heading4.copyWith(
                                          fontSize: 12, color: Colors.black54),
                                    ),
                                  ),
                                  hspace(10)
                                ],
                              ),
                            ),
                      controller: widget.addressController,
                      hintText: "Alamat",
                      padding: const EdgeInsets.fromLTRB(10, 10, 10, 0),
                    ),
                    vspace(20),
                    widget.footer ?? Container(),
                    vspace(20),
                    SizedBox(
                      width: 200,
                      child: TextButton(
                          onPressed: widget.onSubmit,
                          child: Text(
                            "Kirim",
                            style: MyTypo.whiteColor,
                          ),
                          style: MyStyle.buttonDefault),
                    )
                  ],
                ),
              )),
        ),
      ),
    );
  }
}

==> 0.0.18.tar.gz: lib/src/pages/registration_page.dart <==
import 'package:ametory_ui/ametory_ui.dart';
import 'package:ametory_ui/src/styles/color.dart';
import 'package:ametory_ui/src/utils/helper/layout.dart';
import 'package:ametory_ui/src/widgets/widget_size.dart';
import 'package:flutter/material.dart';

class MyRegistrationPage extends StatefulWidget {
  final Color? backgroundColor;
  final Color? boxColor;
  final BorderRadius? boxRadius;
  final Widget? title;
  final Widget? subtitle;
  final Widget? footer;
  final Widget? header;
  final List<BoxShadow>? boxShadow;
  final double? boxWidth;
  final double? boxHeight;
  final TextEditingController? nameController;
  final TextEditingController? emailController;
  final TextEditingController? phoneController;
  final TextEditingController? addressController;
  final TextEditingController? passwordController;
  final TextEditingController? confirmController;
  final Function()? onSubmit;
  final Gradient? gradient;
  MyRegistrationPage(
      {Key? key,
      this.boxWidth,
      this.backgroundColor,
      this.boxColor,
      this.boxRadius,
      this.boxShadow,
      this.title,
      this.subtitle,
      this.boxHeight,
      this.onSubmit,
      this.nameController,
      this.footer,
      this.header,
      this.emailController,
      this.phoneController,
      this.addressController,
      this.passwordController,
      this.confirmController,
      this.gradient})
      : super(key: key);

  @override
  State<MyRegistrationPage> createState() => _MyRegistrationPageState();
}

class _MyRegistrationPageState extends State<MyRegistrationPage> {
  double? width;
  double? height;
  final _key = GlobalKey();
  bool obscureText = true;

// This function is trggered somehow after build() called
  @override
  Widget build(BuildContext context) {
    return Container(
      width: double.infinity,
      height: double.infinity,
      decoration: BoxDecoration(
          color: widget.backgroundColor ?? MyColor.info,
          gradient: widget.gradient ??
              LinearGradient(colors: [
                MyColor.info,
                MyColor.info.shade100,
              ], begin: Alignment.topCenter, end: Alignment.bottomCenter)),
      child: Container(
        padding:
            EdgeInsets.all(ResponsiveWidget.isSmallScreen(context) ? 20 : 40),
        alignment: Alignment.center,
        child: WidgetSize(
          onChange: (Size size) {
            width = size.width;
            height = size.height;
            setState(() {});
          },
          child: Container(
              decoration: BoxDecoration(
                  boxShadow: widget.boxShadow ??
                      [const BoxShadow(color: Colors.black45, blurRadius: 10)],
                  color: widget.boxColor ?? Colors.white,
                  borderRadius: widget.boxRadius ?? BorderRadius.circular(10)),
              padding: EdgeInsets.all(
                  ResponsiveWidget.isSmallScreen(context) ? 20 : 40),
              width: ResponsiveWidget.isSmallScreen(context)
                  ? double.infinity
                  : widget.boxWidth ?? 800,
              // height: widget.boxHeight ?? MediaQuery.of(context).size.height,
              child: SingleChildScrollView(
                child: Column(
                  children: [
                    widget.title ??
                        Text(
                          "Pendaftaran",
                          style: MyTypo.heading1,
                        ),
                    vspace(10),
                    widget.subtitle ??
                        Text(
                          "Silakan isi data lengkap anda",
                          style: MyTypo.bodyText1,
                        ),
                    vspace(40),
                    widget.header ?? Container(),
                    Input(
                      leading: !ResponsiveWidget.isLargeScreen(context)
                          ? null
                          : SizedBox(
                              child: Row(
                                children: [
                                  SizedBox(
                                    width: width != null ? width! / 8 : 0,
                                    child: Text(
                                      "Nama Lengkap",
                                      style: MyTypo.heading4.copyWith(
                                          fontSize: 12, color: Colors.black54),
                                    ),
                                  ),
                                  hspace(10)
                                ],
                              ),
                            ),
                      controller: widget.nameController,
                      hintText: "Nama Lengkap",
                      padding: const EdgeInsets.fromLTRB(10, 0, 10, 0),
                    ),
                    vspace(20),
                    Row(
                      children: [
                        Flexible(
                          child: Input(
                            keyboardType: TextInputType.emailAddress,
                            leading: !ResponsiveWidget.isLargeScreen(context)
                                ? null
                                : SizedBox(
                                    child: Row(
                                      children: [
                                        SizedBox(
                                          width: width != null ? width! / 8 : 0,
                                          child: Text(
                                            "Email",
                                            style: MyTypo.heading4.copyWith(
                                                fontSize: 12,
                                                color: Colors.black54),
                                          ),
                                        ),
                                        hspace(10)
                                      ],
                                    ),
                                  ),
                            controller: widget.emailController,
                            hintText: "Email",
                            padding: const EdgeInsets.fromLTRB(10, 0, 10, 0),
                          ),
                        ),
                        hspace(10),
                        Flexible(
                          child: Input(
                            keyboardType: TextInputType.number,
                            leading: !ResponsiveWidget.isLargeScreen(context)
                                ? null
                                : SizedBox(
                                    child: Row(
                                      children: [
                                        SizedBox(
                                          width: width != null ? width! / 8 : 0,
                                          child: Text(
                                            "Telepon",
                                            style: MyTypo.heading4.copyWith(
                                                fontSize: 12,
                                                color: Colors.black54),
                                          ),
                                        ),
                                        hspace(10)
                                      ],
                                    ),
                                  ),
                            controller: widget.phoneController,
                            hintText: "Telepon",
                            padding: const EdgeInsets.fromLTRB(10, 0, 10, 0),
                          ),
                        ),
                      ],
                    ),
                    vspace(20),
                    Row(
                      children: [
                        Flexible(
                          child: Input(
                            obscureText: obscureText,
                            leading: !ResponsiveWidget.isLargeScreen(context)
                                ? null
                                : SizedBox(
                                    child: Row(
                                      children: [
                                        SizedBox(
                                          width: width != null ? width! / 8 : 0,
                                          child: Text(
                                            "Password",
                                            style: MyTypo.heading4.copyWith(
                                                fontSize: 12,
                                                color: Colors.black54),
                                          ),
                                        ),
                                        hspace(10)
                                      ],
                                    ),
                                  ),
                            controller: widget.passwordController,
                            hintText: "Password",
                            padding: const EdgeInsets.fromLTRB(10, 0, 10, 0),
                            trailing: InkWell(
                              onTap: () =>
                                  setState(() => obscureText = !obscureText),
                              child: const Icon(
                                Icons.remove_red_eye_outlined,
                                size: 16,
                                color: Colors.black38,
                              ),
                            ),
                          ),
                        ),
                        hspace(10),
                        Flexible(
                          child: Input(
                            obscureText: obscureText,
                            leading: !ResponsiveWidget.isLargeScreen(context)
                                ? null
                                : SizedBox(
                                    child: Row(
                                      children: [
                                        SizedBox(
                                          width: width != null ? width! / 8 : 0,
                                          child: Text(
                                            "Ulangi",
                                            style: MyTypo.heading4.copyWith(
                                                fontSize: 12,
                                                color: Colors.black54),
                                          ),
                                        ),
                                        hspace(10)
                                      ],
                                    ),
                                  ),
                            controller: widget.confirmController,
                            hintText: "Ulangi Password",
                            padding: const EdgeInsets.fromLTRB(10, 0, 10, 0),
                            trailing: InkWell(
                              onTap: () =>
                                  setState(() => obscureText = !obscureText),
                              child: const Icon(
                                Icons.remove_red_eye_outlined,
                                size: 16,
                                color: Colors.black38,
                              ),
                            ),
                          ),
                        ),
                      ],
                    ),
                    vspace(20),
                    Input(
                      height: null,
                      maxLine: 3,
                      leading: !ResponsiveWidget.isLargeScreen(context)
                          ? null
                          : SizedBox(
                              child: Row(
                                children: [
                                  SizedBox(
                                    width: width != null ? width! / 8 : 0,
                                    child: Text(
                                      "Alamat",
                                      style: MyTypo.heading4.copyWith(
                                          fontSize: 12, color: Colors.black54),
                                    ),
                                  ),
                                  hspace(10)
                                ],
                              ),
                            ),
                      controller: widget.addressController,
                      hintText: "Alamat",
                      padding: const EdgeInsets.fromLTRB(10, 10, 10, 0),
                    ),
                    vspace(20),
                    widget.footer ?? Container(),
                    vspace(20),
                    SizedBox(
                      width: 200,
                      child: TextButton(
                          onPressed: widget.onSubmit,
                          child: Text(
                            "Kirim",
                            style: MyTypo.whiteColor,
                          ),
                          style: MyStyle.buttonDefault),
                    )
                  ],
                ),
              )),
        ),
      ),
    );
  }
}
